import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.*;

/**
 * Displays the current score
 * 
 * @author PriyaMeena Naitheevani Raj
 * @version 2.0.1
 */
public class Score  extends Actor
{
    private myWorld mworld;
    private static final Color textColor = new Color(255, 165, 0);
    Font font = new Font ("Serif", 1, 20);
    public static int score = 0;
    
    /**
     * addedToWorld - allows class to access world variables
     */
    public void addedToWorld(World world)
    {
        mworld = (myWorld) world;
    } // end addedToWorld
    
    /**
     * Score - class constructor. Sets up the display for the score
     */
    public Score(String string)
    {
        GreenfootImage img = new GreenfootImage(75, 50);
        
        img.setFont(font);
        img.setColor(textColor);
        img.drawString(string, 0, 20);
        setImage(img);  
        score = mworld.getBackupScore();
    }
    
    /**
     * Act - do whatever the Score wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        updateScore();
    }    
       
    /**
     * updateScore - Determines how many tries a user took to get the correct answer
     * and uses that to determine how many points to award the user
     */
    public void updateScore()
    { 
        changeScore("coins " +score);
        
        // correct on first try
        if (mworld.numOfTries == 1 && mworld.correct == 1)
        {
            score += 5;
            changeScore("coins "+score);
            mworld.numOfTries = 0;
        }
        
        // correct on second try
        if (mworld.numOfTries == 2 && mworld.correct == 1)
        {
            score += 1;
            changeScore("coins "+score);
            mworld.numOfTries = 0;
        }
        
        // correct on third try OR
        // if user clicked the same wrong answer more than two times
        if (mworld.numOfTries >= 3 && mworld.correct == 1)
        {
            score -= 3;
            changeScore("coins "+score);
            mworld.numOfTries = 0;
        }   
    } // end updateScore
    
    /**
     * changeScore - updates the display with the current score
     * @param string - a String that is displayed before the score itself
     */
    public void changeScore(String string)
    {
        GreenfootImage img = getImage();
        img.clear();
        img.drawString(string, 0, 20);
    }
}
