import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.lang.*;
/**
 * This is the World class which several other classes refer to. This class holds all the world variables and changes levels when appropriate
 * 
 * @author Priya, Alex, Venkata
 * @version 1.0
 */
public class myWorld  extends World
{
    /**
     * coordinate for setCoordinates method
     */
    static public int coordsX, coordsY;
    
    /**
     * keeps track of when puzzle mode is active
     */
    static public boolean puzzle = false; 
    
    /**
     * current game level
     */
    public static int level = 0; 
    
    /**
     * keeps track of the users answer; 0 = null, 1 = answer is correct, 2 = answer is false
     */
    public static int correct = 0; 
    
    /**
     * current question in any given level
     */
    public static int currentQuestion = 1;
    
    /**
     * keeps track of when it is time to update the score
     */
    public boolean updateScore = false;
    
    /**
     * number of attempts at answering a question
     */
    public static int numOfTries = 0; 
    
    /**
     * backs up current score to load for next level
     */
    public static int backupScore = 0;

    GreenfootSound music1 = new GreenfootSound("aliceAndPaul.mp3");
    GreenfootSound music2 = new GreenfootSound("MagicToy.mp3");
    GreenfootSound music3 = new GreenfootSound("TheBestEver2.mp3");
    GreenfootSound music4 = new GreenfootSound("HolidayInMusic.mp3");

    /**
     * myWorld - Determines the size of the game screen,
     * also sets up the initial game level
     */
    public myWorld()
    {    
        // Create a new world with 750x598 cells with a cell size of 1x1 pixels.
        super(750, 598, 1); 
        
        changeLvl(0);
    } // end myWorld
    
    /**
     * changeLvl - Changes the current level of the game, and prepares each level with the appropriate objects and background music
     * @param whichLvl An integer that represents the level we want to switch to
     */
    public void changeLvl(int whichLvl) 
    {
        level = whichLvl; // sets world level variables
        lvlSwitch(level); 

        // prepares each level with the appropriate objects & music
        if (level == 1)
        {
            backupScore = 0;
            puzzle = false;
            music1.playLoop();
            prepare1();
        }
        if (level == 2)
        {
            music1.stop();
            music2.playLoop();
            prepare2();
        }
        if (level == 3)
        {
            music2.stop();
            music3.playLoop();
            prepare3();
        }
        if (level == 4)
        {
            music3.stop();
            music4.playLoop();
            prepare4();
        }
        if (level == 5)
        {
            music4.stop();
            //music5.playLoop();
            prepare5();
        }
        if (level == 97)
        {
            music1.stop();
            music2.stop();
            music3.stop();
            music4.stop();
        }
        
    } // end changeLvl
    
    /**
     * setBackupScore - Prevents current score from being reset each level by saving a copy of it to reload at the beginning of each level
     * @param x an integer represented the current score
     */
    public void setBackupScore(int x)
    {
        backupScore = x;
    }
    
    /**
     * getBackupScore - Retrieves the backup score for each new level
     */
    public static int getBackupScore()
    {
        return backupScore;
    }    
    
    /**
     * setCoords - Sets the x and y coordinates of the player for reference in other classes
     * @param x x-axis coordinate
     * @param y y-axis coordinate
     */
    
    public void setCoords(int x, int y)
    {
        coordsX = x;
        coordsY = y;
    } // end setCoords

    /**
     * cleanWorld - Removes all objects from the world
     */
    public void cleanWorld()
    {
        removeObjects(getObjects(null));
    } // end cleanWorld

    /**
     * lvlSwitch - Adds a new level object into the world,
     * also adds objects for when the player wins or loses
     */
    private void lvlSwitch(int whichLvl)
    {
        switch(whichLvl)
        {
            case 0:
            {
                cleanWorld();
                level0 level0_1 = new level0();
                addObject(level0_1, 0, 0);
            }
            case 1:
            {
                cleanWorld();
                level1 level1 = new level1();
                addObject(level1, 0, 0);
            }
            case 2:
            {
                cleanWorld();
                level2 level2 = new level2();
                addObject(level2, 0, 0);
            }
            case 3:
            {
                cleanWorld();
                level3 level3 = new level3();
                addObject(level3, 0, 0);
            }
            case 4:
            {
                cleanWorld();
                level4 level4 = new level4();
                addObject(level4, 0, 0);
            }
            
            /*case 5:
            {
                cleanWorld();
                level5 level5_1 = new level5();
                addObject(level5_1, 0, 0);
            }*/

            
            
            // PLAYER WINS
            case 5:
            {
                cleanWorld();
                win win = new win();
                addObject(win, 0, 0);
            }
            
            // PLAYER LOSES
            case 97:
            {
                cleanWorld();
                lose lose = new lose();
                addObject(lose, 0, 0);
            }
            
            // START OF GAME
            case 98:
            {
                cleanWorld();
                level0 level0_2 = new level0();
                addObject(level0_2, 0, 0);
            }
            case 99:
            {
                cleanWorld();
                level0 level0_3 = new level0();
                addObject(level0_3, 0, 0);
            }
            
            case 100:
            {
                cleanWorld();
                level0 level0_4 = new level0();
                addObject(level0_4, 0, 0);
            }
        } // end switch
    } // end lvlSwitch

    // OBJECTS FOR LEVEL 5
    private void prepare5()
    {
        endScore endscore = new endScore();
        addObject(endscore, 520, 462);
        endMessage endMessage = new endMessage();
        addObject(endMessage, 520, 500);
    }
    
    // OBJECTS FOR LEVEL 4
    private void prepare4()
    {
        seaweed seaweed12 = new seaweed();
        addObject(seaweed12, 100, 100);
        seaweed seaweed13 = new seaweed();
        addObject(seaweed13, 100, 50);
        seaweed seaweed14 = new seaweed();
        addObject(seaweed14, 100, 0);
        seaweed seaweed = new seaweed();
        addObject(seaweed, 100, 150);
        seaweed seaweed3 = new seaweed();
        addObject(seaweed3, 100, 200);
        seaweed seaweed15 = new seaweed();
        addObject(seaweed15, 150, 200);
        seaweed seaweed4 = new seaweed();
        addObject(seaweed4, 200, 200);
        seaweed seaweed5 = new seaweed();
        addObject(seaweed5, 250, 200);
        seaweed seaweed6 = new seaweed();
        addObject(seaweed6, 300, 200);
        seaweed seaweed7 = new seaweed();
        addObject(seaweed7, 350, 200);
        seaweed seaweed8 = new seaweed();
        addObject(seaweed8, 400, 200);
        seaweed seaweed9 = new seaweed();
        addObject(seaweed9, 450, 200);
        seaweed seaweed10 = new seaweed();
        addObject(seaweed10, 500, 200);
        seaweed seaweed11 = new seaweed();
        addObject(seaweed11, 550, 200);
        seaweed seaweed2 = new seaweed();
        addObject(seaweed2, 600, 200);
        seaweed seaweed16 = new seaweed();
        addObject(seaweed16, 250, 22);
        seaweed16.setLocation(250, 5);
        seaweed seaweed17 = new seaweed();
        addObject(seaweed17, 250, 50);
        seaweed seaweed18 = new seaweed();
        addObject(seaweed18, 300, 50);
        seaweed seaweed19 = new seaweed();
        addObject(seaweed19, 350, 50);
        seaweed seaweed20 = new seaweed();
        addObject(seaweed20, 400, 50);
        seaweed seaweed21 = new seaweed();
        addObject(seaweed21, 450, 50);
        seaweed seaweed22 = new seaweed();
        addObject(seaweed22, 500, 50);
        seaweed seaweed23 = new seaweed();
        addObject(seaweed23, 550, 50);
        seaweed seaweed24 = new seaweed();
        addObject(seaweed24, 600, 50);
        seaweed seaweed25 = new seaweed();
        addObject(seaweed25, 650, 50);
        seaweed seaweed26 = new seaweed();
        addObject(seaweed26, 700, 50);
        seaweed seaweed27 = new seaweed();
        addObject(seaweed27, 750, 100);
        seaweed seaweed28 = new seaweed();
        addObject(seaweed28, 750, 150);
        seaweed seaweed29 = new seaweed();
        addObject(seaweed29, 750, 200);
        seaweed seaweed30 = new seaweed();
        addObject(seaweed30, 600, 250);
        seaweed seaweed31 = new seaweed();
        addObject(seaweed31, 750, 250);
        seaweed seaweed32 = new seaweed();
        addObject(seaweed32, 600, 300);
        seaweed seaweed33 = new seaweed();
        addObject(seaweed33, 750, 350);
        seaweed seaweed34 = new seaweed();
        addObject(seaweed34, 700, 450);
        seaweed seaweed35 = new seaweed();
        addObject(seaweed35, 750, 400);
        seaweed seaweed37 = new seaweed();
        addObject(seaweed37, 650, 450);
        seaweed seaweed49 = new seaweed();
        addObject(seaweed49, 350, 300);
        seaweed seaweed50 = new seaweed();
        addObject(seaweed50, 350, 450);
        seaweed seaweed57 = new seaweed();
        addObject(seaweed57, 750, 300);
        seaweed seaweed59 = new seaweed();
        addObject(seaweed59, 750, 50);
        seaweed seaweed46 = new seaweed();
        addObject(seaweed46, 500, 300);
        seaweed seaweed47 = new seaweed();
        addObject(seaweed47, 450, 300);
        seaweed seaweed43 = new seaweed();
        addObject(seaweed43, 550, 300);
        seaweed seaweed44 = new seaweed();
        addObject(seaweed44, 400, 300);
        seaweed seaweed45 = new seaweed();
        addObject(seaweed45, 750, 450);
        seaweed seaweed70 = new seaweed();
        addObject(seaweed70, 600, 450);
        seaweed seaweed71 = new seaweed();
        addObject(seaweed71, 500, 450);
        seaweed seaweed72 = new seaweed();
        addObject(seaweed72, 350, 400);
        seaweed seaweed73 = new seaweed();
        addObject(seaweed73, 350, 450);
        seaweed seaweed74 = new seaweed();
        addObject(seaweed74, 350, 350);
        seaweed seaweed75 = new seaweed();
        addObject(seaweed75, 550, 450);
        
        cityPath2 citypath2 = new cityPath2();
        addObject(citypath2, 368, 471);
        cityPath2 citypath23 = new cityPath2();
        addObject(citypath23, 393, 471);
        cityPath2 citypath21 = new cityPath2();
        addObject(citypath21, 420, 471);
        cityPath2 citypath24 = new cityPath2();
        addObject(citypath24, 455, 471);
        cityPath2 citypath22 = new cityPath2();
        addObject(citypath22, 470, 471);
        
        coinImage coinimage = new coinImage();
        addObject(coinimage, 620, 546);
        levelImage lvlimage = new levelImage();
        addObject(lvlimage, 395, 550);
        Score score2 = new Score("coins 0");
        addObject(score2, 704, 562);
        levelCounter levelcounter2 = new levelCounter("level");
        addObject(levelcounter2, 504, 549);
        timerImg timerimg = new timerImg();
        addObject(timerimg, 74, 543);
        timer timer = new timer("time left:");
        addObject(timer, 250, 549);
        
        player player = new player();
        addObject(player, 423, 413);
        
        pufferfish pufferfish = new pufferfish();
        addObject(pufferfish, 190, 127);
        pufferfish pufferfish2 = new pufferfish();
        addObject(pufferfish2, 415, 127);
        pufferfish pufferfish3 = new pufferfish();
        addObject(pufferfish3, 659, 127);
        pufferfish pufferfish4 = new pufferfish();
        addObject(pufferfish4, 659, 379);
        
        end end = new end();
        addObject(end, 142, 10);
        end end2 = new end();
        addObject(end2, 170, 10);
        end end3 = new end();
        addObject(end3, 202, 10);
        
        // location of question box
        puzzle puzzle = new puzzle();
        //addObject(puzzle, 570, 60);
        addObject(puzzle, 170, 310);

        // locations of answer boxes
        answer1_1 answer1_1 = new answer1_1();
        addObject(answer1_1, 70, 375); 
        answer1_2 answer1_2 = new answer1_2();
        addObject(answer1_2, 170, 375);
        answer1_3 answer1_3 = new answer1_3();
        addObject(answer1_3, 270, 375); 
    }
    
    // OBJECTS FOR LEVEL 3
    private void prepare3()
    {
        seashell seashell = new seashell();
        addObject(seashell, 485, 95);
        seashell seashell3 = new seashell();
        addObject(seashell3, 485, 115);
        seashell seashell4 = new seashell();
        addObject(seashell4, 485, 135);
        seashell seashell5 = new seashell();
        addObject(seashell5, 485, 155);
        seashell seashell6 = new seashell();
        addObject(seashell6, 485, 175);
        seashell seashell7 = new seashell();
        addObject(seashell7, 485, 195);
        seashell seashell8 = new seashell();
        addObject(seashell8, 485, 215);
        seashell seashell9 = new seashell();
        addObject(seashell9, 485, 235);
        seashell seashell10 = new seashell();
        addObject(seashell10, 460, 235);
        seashell seashell11 = new seashell();
        addObject(seashell11, 435, 235);
        seashell seashell12 = new seashell();
        addObject(seashell12, 410, 235);
        seashell seashell13 = new seashell();
        addObject(seashell13, 385, 235);
        seashell seashell14 = new seashell();
        addObject(seashell14, 360, 235);
        seashell seashell15 = new seashell();
        addObject(seashell15, 335, 235);
        seashell seashell16 = new seashell();
        addObject(seashell16, 310, 235);
        seashell seashell17 = new seashell();
        addObject(seashell17, 285, 235);
        seashell seashell18 = new seashell();
        addObject(seashell18, 260, 235);
        seashell seashell19 = new seashell();
        addObject(seashell19, 235, 235);
        seashell seashell20 = new seashell();
        addObject(seashell20, 210, 235);
        seashell seashell21 = new seashell();
        addObject(seashell21, 210, 255);
        seashell seashell22 = new seashell();
        addObject(seashell22, 210, 275);
        seashell seashell23 = new seashell();
        addObject(seashell23, 210, 295);
        seashell seashell24 = new seashell();
        addObject(seashell24, 210, 315);
        seashell seashell25 = new seashell();
        addObject(seashell25, 210, 335);
        seashell seashell26 = new seashell();
        addObject(seashell26, 210, 355);
        seashell seashell27 = new seashell();
        addObject(seashell27, 210, 375);
        seashell seashell28 = new seashell();
        addObject(seashell28, 210, 395);
        seashell seashell29 = new seashell();
        addObject(seashell29, 210, 415);
        seashell seashell30 = new seashell();
        addObject(seashell30, 210, 435);
        seashell seashell31 = new seashell();
        addObject(seashell31, 210, 455);
        seashell seashell32 = new seashell();
        addObject(seashell32, 210, 475);
        
        seashell seashell2 = new seashell();
        addObject(seashell2, 575, 95);
        seashell seashell33 = new seashell();
        addObject(seashell33, 575, 115);
        seashell seashell34 = new seashell();
        addObject(seashell34, 575, 135);
        seashell seashell35 = new seashell();
        addObject(seashell35, 575, 155);
        seashell seashell36 = new seashell();
        addObject(seashell36, 575, 175);
        seashell seashell37 = new seashell();
        addObject(seashell37, 575, 195);
        seashell seashell38 = new seashell();
        addObject(seashell38, 575, 215);
        seashell seashell39 = new seashell();
        addObject(seashell39, 575, 235);
        seashell seashell40 = new seashell();
        addObject(seashell40, 575, 255);
        seashell seashell41 = new seashell();
        addObject(seashell41, 575, 275);
        seashell seashell42 = new seashell();
        addObject(seashell42, 575, 295);
        seashell seashell43 = new seashell();
        addObject(seashell43, 575, 315);
        seashell seashell44 = new seashell();
        addObject(seashell44, 575, 315);
        seashell seashell45 = new seashell();
        addObject(seashell45, 550, 315);
        seashell seashell46 = new seashell();
        addObject(seashell46, 525, 315);
        seashell seashell47 = new seashell();
        addObject(seashell47, 500, 315);
        seashell seashell48 = new seashell();
        addObject(seashell48, 475, 315);
        seashell seashell49 = new seashell();
        addObject(seashell49, 450, 315);
        seashell seashell50 = new seashell();
        addObject(seashell50, 425, 315);
        seashell seashell51 = new seashell();
        addObject(seashell51, 400, 315);
        seashell seashell52 = new seashell();
        addObject(seashell52, 375, 315);
        seashell seashell53 = new seashell();
        addObject(seashell53, 350, 315);
        seashell seashell54 = new seashell();
        addObject(seashell54, 325, 315);
        seashell seashell55 = new seashell();
        addObject(seashell55, 300, 315);
        seashell seashell56 = new seashell();
        addObject(seashell56, 300, 335);
        seashell seashell57 = new seashell();
        addObject(seashell57, 300, 355);
        seashell seashell58 = new seashell();
        addObject(seashell58, 300, 375);
        seashell seashell59 = new seashell();
        addObject(seashell59, 300, 395);
        seashell seashell60 = new seashell();
        addObject(seashell60, 300, 415);
        seashell seashell61 = new seashell();
        addObject(seashell61, 300, 435);
        seashell seashell62 = new seashell();
        addObject(seashell62, 300, 455);
        seashell seashell63 = new seashell();
        addObject(seashell63, 300, 475);
        
        cityPath2 citypath = new cityPath2();
        addObject(citypath, 237, 476);
        cityPath2 citypath2 = new cityPath2();
        addObject(citypath2, 275, 476);
        end end = new end();
        addObject(end, 519, 93);
        end end2 = new end();
        addObject(end2, 541, 93);
        
        coinImage coinimage = new coinImage();
        addObject(coinimage, 620, 546);
        levelImage lvlimage = new levelImage();
        addObject(lvlimage, 395, 550);
        Score score2 = new Score("coins 0");
        addObject(score2, 704, 562);
        levelCounter levelcounter2 = new levelCounter("level");
        addObject(levelcounter2, 504, 549);
        timerImg timerimg = new timerImg();
        addObject(timerimg, 74, 543);
        timer timer = new timer("time left:");
        addObject(timer, 250, 549);
        
        player player = new player();
        addObject(player, 253, 462);
        crab crab = new crab();
        addObject(crab, 256, 354);
        brokenbottle brokenbottle = new brokenbottle();
        addObject(brokenbottle, 370, 273);
        beachball beachball = new beachball();
        addObject(beachball, 526, 265);
        starfish starfish = new starfish();
        addObject(starfish, 529, 149);
        
        puzzle puzzle = new puzzle();
        addObject(puzzle, 220, 60);

        answer1_1 answer1_1 = new answer1_1();
        addObject(answer1_1, 120, 125); 
        answer1_2 answer1_2 = new answer1_2();
        addObject(answer1_2, 220, 125);
        answer1_3 answer1_3 = new answer1_3();
        addObject(answer1_3, 320, 125); 
        
        seaweed seaweed = new seaweed();
        addObject(seaweed, 408, 378);
        seaweed seaweed2 = new seaweed();
        addObject(seaweed2, 531, 434);
        submarine submarine = new submarine();
        addObject(submarine, 678, 35);
    }
    
    // OBJECTS FOR LEVEL 2
    private void prepare2()
    {
        cityPath citypath = new cityPath();
        addObject(citypath, 460, 17);
        cityPath citypath2 = new cityPath();
        addObject(citypath2, 460, 55);
        cityPath citypath3 = new cityPath();
        addObject(citypath3, 464, 94);
        cityPath citypath4 = new cityPath();
        addObject(citypath4, 460, 132);
        cityPath citypath5 = new cityPath();
        addObject(citypath5, 463, 174);
        cityPath2 citypath22 = new cityPath2();
        addObject(citypath22, 446, 191);
        cityPath2 citypath23 = new cityPath2();
        addObject(citypath23, 415, 202);
        cityPath2 citypath24 = new cityPath2();
        addObject(citypath24, 390, 220);
        cityPath2 citypath25 = new cityPath2();
        addObject(citypath25, 355, 237);
        cityPath2 citypath26 = new cityPath2();
        addObject(citypath26, 334, 258);
        citypath26.setLocation(324, 251);
        citypath25.setLocation(355, 234);
        cityPath2 citypath27 = new cityPath2();
        addObject(citypath27, 292, 255);
        cityPath2 citypath28 = new cityPath2();
        addObject(citypath28, 254, 255);
        cityPath2 citypath29 = new cityPath2();
        addObject(citypath29, 219, 265);
        cityPath2 citypath210 = new cityPath2();
        addObject(citypath210, 176, 279);
        cityPath2 citypath211 = new cityPath2();
        addObject(citypath211, 145, 289);
        cityPath2 citypath212 = new cityPath2();
        addObject(citypath212, 103, 300);
        cityPath2 citypath213 = new cityPath2();
        addObject(citypath213, 68, 307);
        cityPath2 citypath214 = new cityPath2();
        addObject(citypath214, 26, 310);
        cityPath citypath6 = new cityPath();
        addObject(citypath6, 555, 20);
        cityPath citypath7 = new cityPath();
        addObject(citypath7, 558, 62);
        cityPath citypath8 = new cityPath();
        addObject(citypath8, 561, 93);
        cityPath citypath9 = new cityPath();
        addObject(citypath9, 562, 139);
        cityPath2 citypath215 = new cityPath2();
        addObject(citypath215, 407, 310);
        cityPath2 citypath216 = new cityPath2();
        addObject(citypath216, 442, 303);
        cityPath2 citypath217 = new cityPath2();
        addObject(citypath217, 471, 283);
        citypath217.setLocation(468, 286);
        cityPath2 citypath218 = new cityPath2();
        addObject(citypath218, 502, 268);
        cityPath2 citypath219 = new cityPath2();
        addObject(citypath219, 541, 258);
        cityPath2 citypath220 = new cityPath2();
        addObject(citypath220, 586, 254);
        cityPath citypath10 = new cityPath();
        addObject(citypath10, 565, 233);
        cityPath citypath11 = new cityPath();
        addObject(citypath11, 569, 192);
        citypath11.setLocation(565, 188);
        cityPath2 citypath221 = new cityPath2();
        addObject(citypath221, 292, 349);
        citypath221.setLocation(251, 342);
        cityPath2 citypath222 = new cityPath2();
        addObject(citypath222, 295, 342);
        cityPath2 citypath223 = new cityPath2();
        addObject(citypath223, 334, 335);
        cityPath2 citypath225 = new cityPath2();
        addObject(citypath225, 229, 356);
        cityPath2 citypath226 = new cityPath2();
        addObject(citypath226, 200, 363);
        cityPath2 citypath227 = new cityPath2();
        addObject(citypath227, 165, 380);
        cityPath2 citypath228 = new cityPath2();
        addObject(citypath228, 141, 388);
        cityPath2 citypath229 = new cityPath2();
        addObject(citypath229, 109, 402);
        cityPath2 citypath230 = new cityPath2();
        addObject(citypath230, 81, 412);
        cityPath2 citypath231 = new cityPath2();
        addObject(citypath231, 46, 416);
        cityPath2 citypath232 = new cityPath2();
        addObject(citypath232, 32, 412);
        citypath232.setLocation(18, 412);
        cityPath2 citypath999 = new cityPath2();
        addObject(citypath999, 354, 325);

        end2 end2 = new end2();
        addObject(end2, 10, 341);
        end2 end21 = new end2();
        addObject(end21, 10, 374);

        coinImage coinimage = new coinImage();
        addObject(coinimage, 620, 546);
        levelImage lvlimage = new levelImage();
        addObject(lvlimage, 395, 550);
        Score score2 = new Score("coins 0");
        addObject(score2, 704, 562);
        levelCounter levelcounter2 = new levelCounter("level");
        addObject(levelcounter2, 504, 549);

        player player = new player();
        addObject(player, 504, 31);

        rock rock = new rock();
        addObject(rock, 507, 119);
        tree tree = new tree();
        addObject(tree, 521, 216);
        waterPuddle waterpuddle = new waterPuddle();
        addObject(waterpuddle, 420, 248);
        rock rock2 = new rock();
        addObject(rock2, 263, 293);
        tree tree2 = new tree();
        addObject(tree2, 95, 349);

        // location of question box
        puzzle puzzle = new puzzle();
        addObject(puzzle, 170, 60);

        // locations of answer boxes
        answer1_1 answer1_1 = new answer1_1();
        addObject(answer1_1, 70, 125); 
        answer1_2 answer1_2 = new answer1_2();
        addObject(answer1_2, 170, 125);
        answer1_3 answer1_3 = new answer1_3();
        addObject(answer1_3, 270, 125); 
        
        timerImg timerimg = new timerImg();
        addObject(timerimg, 74, 543);
        timer timer = new timer("time left:");
        addObject(timer, 250, 549);
    }

    // OBJECTS FOR LEVEL 1
    private void prepare1()
    {

        path2 path2 = new path2();
        addObject(path2, 43, 29);
        path2.setLocation(36, 22);
        path2 path22 = new path2();
        addObject(path22, 36, 64);
        path2 path23 = new path2();
        addObject(path23, 36, 123);
        path23.setLocation(36, 99);
        path2 path24 = new path2();
        addObject(path24, 82, 74);
        path24.setLocation(127, 22);
        path path = new path();
        addObject(path, 201, 176);
        path2 path25 = new path2();
        addObject(path25, 43, 147);
        path25.setLocation(36, 130);
        path.setLocation(48, 159);
        path.setLocation(51, 159);
        path.setLocation(205, 159);
        path25.setLocation(36, 144);
        path.setLocation(66, 159);
        path path3 = new path();
        addObject(path3, 120, 172);
        path3.setLocation(113, 161);
        path3.setLocation(145, 162);
        path.setLocation(67, 159);
        path3.setLocation(114, 159);
        path path4 = new path();
        addObject(path4, 211, 183);
        path4.setLocation(159, 159);
        path path5 = new path();
        addObject(path5, 211, 162);
        path5.setLocation(204, 158);
        path5.setLocation(200, 158);
        path5.setLocation(204, 158);
        path5.setLocation(201, 158);
        path2 path26 = new path2();
        addObject(path26, 134, 78);
        path26.setLocation(127, 67);
        path5.setLocation(250, 175);
        path5.setLocation(253, 214);
        path5.setLocation(250, 207);
        path5.setLocation(253, 186);
        path path6 = new path();
        addObject(path6, 292, 169);
        path6.setLocation(284, 238);
        path5.setLocation(141, 99);
        path6.setLocation(270, 245);
        path path7 = new path();
        addObject(path7, 193, 102);
        path7.setLocation(187, 99);
        path path8 = new path();
        addObject(path8, 236, 102);
        path8.setLocation(232, 99);
        path2 path27 = new path2();
        addObject(path27, 271, 120);
        path27.setLocation(264, 113);
        path6.setLocation(392, 346);
        path27.setLocation(442, 235);
        path path9 = new path();
        addObject(path9, 277, 99);
        path27.setLocation(292, 131);
        path27.setLocation(397, 239);
        path path10 = new path();
        addObject(path10, 207, 158);
        path10.setLocation(340, 333);
        path path11 = new path();
        addObject(path11, 207, 158);
        path11.setLocation(204, 172);
        path11.setLocation(319, 224);
        path11.setLocation(336, 206);
        path11.setLocation(305, 241);
        path path12 = new path();
        addObject(path12, 200, 154);
        path12.setLocation(204, 158);
        path9.setLocation(277, 99);
        path12.setLocation(320, 99);
        path11.setLocation(465, 223);
        path27.setLocation(334, 124);
        path27.setLocation(368, 215);
        path.setLocation(50, 173);
        path3.setLocation(97, 173);
        path4.setLocation(142, 173);
        path11.setLocation(186, 171);
        path11.setLocation(189, 174);
        path5.setLocation(141, 113);
        path26.setLocation(127, 80);
        path24.setLocation(127, 22);
        path26.setLocation(127, 42);
        path5.setLocation(281, 158);
        path27.setLocation(127, 89);
        path7.setLocation(141, 106);
        path8.setLocation(187, 106);
        path9.setLocation(232, 106);
        path12.setLocation(275, 106);
        path5.setLocation(319, 106);
        path11.setLocation(381, 198);
        path.setLocation(50, 169);
        path3.setLocation(251, 177);
        path4.setLocation(96, 169);
        path3.setLocation(143, 170);
        path3.setLocation(486, 208);
        path6.setLocation(318, 244);
        path10.setLocation(141, 169);
        path3.setLocation(185, 169);
        path11.setLocation(367, 205);
        path6.setLocation(325, 272);
        path11.setLocation(364, 246);
        path path13 = new path();
        addObject(path13, 372, 112);
        path13.setLocation(418, 290);
        path path14 = new path();
        addObject(path14, 365, 106);
        path11.setLocation(410, 106);
        path2 path28 = new path2();
        addObject(path28, 435, 127);
        path28.setLocation(442, 120);
        path28.setLocation(425, 138);
        path2 path29 = new path2();
        addObject(path29, 432, 193);
        path29.setLocation(425, 166);
        path2 path210 = new path2();
        addObject(path210, 435, 225);
        path210.setLocation(425, 212);
        path2 path211 = new path2();
        addObject(path211, 431, 256);
        path13.setLocation(317, 328);
        path211.setLocation(425, 256);
        path2 path212 = new path2();
        addObject(path212, 425, 305);
        path212.setLocation(425, 298);
        path path15 = new path();
        addObject(path15, 229, 169);
        path path16 = new path();
        addObject(path16, 274, 168);
        path16.setLocation(274, 169);
        path6.setLocation(342, 262);
        path path17 = new path();
        addObject(path17, 320, 169);
        path6.setLocation(342, 391);
        path6.setLocation(401, 478);
        path13.setLocation(331, 464);
        path2 path216 = new path2();
        addObject(path216, 334, 242);
        path2 path217 = new path2();
        addObject(path217, 334, 287);
        path2 path218 = new path2();
        addObject(path218, 334, 329);
        path13.setLocation(236, 446);
        path2 path220 = new path2();
        addObject(path220, 425, 343);
        path6.setLocation(666, 432);
        path2 path221 = new path2();
        addObject(path221, 424, 386);
        path221.setLocation(425, 390);
        path13.setLocation(313, 342);
        path13.setLocation(316, 345);
        path2 path222 = new path2();
        addObject(path222, 425, 431);
        path6.setLocation(401, 449);
        path6.setLocation(621, 456);
        path path18 = new path();
        addObject(path18, 396, 445);
        path18.setLocation(410, 448);
        path6.setLocation(600, 460);
        path13.setLocation(582, 478);
        path2 path223 = new path2();
        addObject(path223, 334, 368);
        path13.setLocation(323, 387);
        path13.setLocation(316, 383);
        path6.setLocation(359, 466);
        path223.setLocation(334, 361);
        path13.setLocation(319, 376);
        path6.setLocation(369, 448);
        path path19 = new path();
        addObject(path19, 323, 448);
        path path20 = new path();
        addObject(path20, 271, 375);
        path20.setLocation(277, 376);
        path2 path230 = new path2();
        addObject(path230, 309, 476);
        path20.setLocation(277, 376);
        path20.setLocation(222, 372);
        path13.setLocation(273, 376);
        path2 path231 = new path2();
        addObject(path231, 337, 196);
        path231.setLocation(334, 200);
        path231.setLocation(334, 200);
        path13.setLocation(304, 376);
        path20.setLocation(256, 376);
        path20.setLocation(259, 376);
        path path41 = new path();
        addObject(path41, 214, 375);
        path41.setLocation(215, 376);
        path2 path232 = new path2();
        addObject(path232, 207, 407);
        path232.setLocation(201, 407);
        path2 path233 = new path2();
        addObject(path233, 201, 449);
        path2 path234 = new path2();
        addObject(path234, 204, 477);
        path234.setLocation(201, 476);
        rock rock = new rock();
        addObject(rock, 382, 407);
        tree tree2 = new tree();
        addObject(tree2, 264, 432);
        tree2.setLocation(253, 424);
        rock.setLocation(376, 404);
        tree2.setLocation(253, 428);
        waterPuddle waterpuddle2 = new waterPuddle();
        addObject(waterpuddle2, 382, 141);
        waterpuddle2.setLocation(378, 151);
        end end = new end();
        addObject(end, 277, 491);
        end.setLocation(277, 491);
        end end2 = new end();
        addObject(end2, 232, 491);
        coinImage coinimage = new coinImage();
        addObject(coinimage, 617, 549);
        coinimage.setLocation(620, 546);
        levelImage levelimage = new levelImage();
        addObject(levelimage, 371, 553);
        levelimage.setLocation(371, 550);
        levelimage.setLocation(395, 553);
        levelimage.setLocation(395, 550);
        levelCounter levelcounter2 = new levelCounter("level");
        addObject(levelcounter2, 494, 538);
        levelcounter2.setLocation(501, 549);
        levelcounter2.setLocation(504, 549);
        player player = new player();
        addObject(player, 78, 31);

        // location of question box
        puzzle puzzle = new puzzle();
        addObject(puzzle, 570, 60);

        // locations of answer boxes
        answer1_1 answer1_1 = new answer1_1();
        addObject(answer1_1, 470, 125); 
        answer1_2 answer1_2 = new answer1_2();
        addObject(answer1_2, 570, 125);
        answer1_3 answer1_3 = new answer1_3();
        addObject(answer1_3, 670, 125); 
        
        waterpuddle2.setLocation(128, 138);
        rock.setLocation(378, 150);
        tree2.setLocation(362, 404);
        Score score2 = new Score("coins 0");
        addObject(score2, 684, 542);
        score2.setLocation(708, 556);
        score2.setLocation(704, 559);
        score2.setLocation(704, 562);

        levelCounter levelcounter3 = new levelCounter("level");
        addObject(levelcounter3, 504, 549);
        
        timerImg timerimg = new timerImg();
        addObject(timerimg, 74, 543);
        timer timer = new timer("time left:");
        addObject(timer, 250, 549);
    }
}
